/* eslint-disable react/no-unescaped-entities */
import React, { PureComponent } from 'react';
import { Card, Icon } from 'antd';
import DescriptionList from '../../components/DescriptionList';
import styles from './document.less';

const { Description } = DescriptionList;

const resourceQAList = [{
  question: '图片的创建与编辑',
  answer: '操作："资源管理 > 图片管理 > 新建/编辑"，正确填写图片的编号和名称后方可选择待上传图片;',
  note: '注意：图片编号应满足格式限制，不填写或者格式错误禁止上传图片',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/image/1/15279977811093052.png',
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/image/2/15280040674381093.png',
  ],
}, {
  question: '视频的创建与编辑',
  answer: '操作："资源管理 > 视频管理 > 新建/编辑"，正确填写视频相关信息',
  note: '注意：视频编号、名称、路径、类型、清晰度、格式为必填项',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/video/1/15280080455214642.png',
  ],
}];
const productQAList = [{
  question: '课件的创建及编辑',
  answer: '操作："产品加工 > 制作课件 > 新建/编辑"，正确填写课件编号及名称等基础信息后，选择课件内容后排序',
  note: '注意：图片课件可包含多张图片资源，视频课件仅能包含一个视频资源，切勿图片与视频混选',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/ware/1/1528009377007865.png',
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/ware/2/15280107071076247.png',
  ],
}, {
  question: '课/课程/配套/师训/套餐包等创建及编辑',
  answer: '此种产品类型的加工过程请参照课件的创建过程',
}];
const shelvesQAList = [{
  question: '产品的上架流程',
  answer: '操作："产品出售 > 上架XX > 新建"，正确选择产品及对应渠道后，提交即可将产品上架到对应渠道',
  note: '注意：新建过程仅仅是将一个产品关联到某渠道，此时前端并未展现，需要再次编辑该产品挂载到相应栏目下，才可展现',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/shelves/1/15280127770612598.png',
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/shelves/2/15280127974934585.png',
  ],
}];
const otherQAList = [{
  question: '如何调整某入口下侧边栏目顺序',
  answer: '操作："前端配置 > 首页入口 > 编辑标签组"，在编辑页面找到该入口下所有栏目表格，拖动或者点击进行排序',
}, {
  question: '如何调整某栏目下的课程排序',
  answer: '操作："前端配置 > 栏目管理 > 编辑标签", 在编辑页面找到已关联的产品后拖动或者上移/下移进行课程排序',
  note: '注意：此处点击关联产品可批量进行课程与栏目关联操作',
}];

function FAQComponent({ sort, bigTitle, qaList }) {
  return (
    <DescriptionList
      col={1}
      size="large"
      title={`${sort}.${bigTitle}`}
      className={styles.descList}
    >
      {/* eslint-disable react/no-array-index-key */}
      {
        qaList.map((qa, index) => {
          const { question, answer, note, imgList } = qa;
          return (
            <div key={index}>
              <Description>
                <Icon type="question-circle-o" className={styles.question} />&nbsp;{question}
              </Description>
              <Description>
                <Icon type="check-circle-o" className={styles.answer} />&nbsp;{answer}
                {note && (<div>&nbsp;&nbsp;&nbsp;&nbsp;{note}</div>)}
              </Description>
              {(imgList && imgList.length) && imgList.map((img, imgIndex) => (
                <Description key={imgIndex}>
                  <img src={img} alt="" style={{ width: '100%', height: 550 }} />
                </Description>
              ))}
            </div>
          );
        })
      }
    </DescriptionList>
  );
}

export default class PlatformDocument extends PureComponent {
  render() {
    return (
      <Card title="平台使用文档" className={styles.card}>
        <FAQComponent
          sort={1}
          bigTitle="资源管理"
          qaList={resourceQAList}
        />
        <FAQComponent
          sort={2}
          bigTitle="产品加工"
          qaList={productQAList}
        />
        <FAQComponent
          sort={3}
          bigTitle="产品上架"
          qaList={shelvesQAList}
        />
        <FAQComponent
          sort={4}
          bigTitle="其他问题"
          qaList={otherQAList}
        />
      </Card>
    );
  }
}
